@@ -38,11 +38,12 @@ const (
 	DEFAULT_SKIPCOLLECTIONS = "system.profile" // comma separated list
 )
 
+// We do not set anything here, these variables are defined by the Makefile
 var (
-	Build     string = "2020-04-23" //nolint
-	GoVersion string = "1.14.1"     //nolint
-	Version   string = "3.5.1"      //nolint
-	Commit    string                //nolint
+	Build     string //nolint
+	GoVersion string //nolint
+	Version   string //nolint
+	Commit    string //nolint
 )
 
 type cliOptions struct {
