@@ -17,11 +17,12 @@ import (
 	"github.com/percona/percona-toolkit/src/go/pt-pg-summary/templates"
 )
 
+// We do not set anything here, these variables are defined by the Makefile
 var (
-	Build     string = "2020-04-23" //nolint
-	Commit    string                //nolint
-	GoVersion string = "1.14.1"     //nolint
-	Version   string = "3.5.1"      //nolint
+	Build     string //nolint
+	GoVersion string //nolint
+	Version   string //nolint
+	Commit    string //nolint
 )
 
 type connOpts struct {
